@@ -25,6 +25,7 @@ has firstLmConfFile            => ( isa => 'Str', is => 'ro', required => 1 );
 has reverseTreeFile            => ( isa => 'Str', is => 'ro', required => 1 );
 has portalConstantsFile        => ( isa => 'Str', is => 'ro', required => 1 );
 has handlerStatusConstantsFile => ( isa => 'Str', is => 'ro', required => 1 );
+has docConstantsFile           => ( isa => 'Str', is => 'ro', required => 1 );
 
 my @managerAttrKeys = qw(keyTest keyMsgFail select type test msgFail default);
 my $format          = 'Creating %-69s: ';
@@ -558,6 +559,43 @@ EOF
     print F $dst;
     close F;
     print STDERR "done\n";
+
+    printf STDERR $format, $self->docConstantsFile;
+
+    # Doc error code list
+    $content = <<EOF;
+..
+   This file is generated by $module. Don't modify it by hand
+
+Error codes list
+================
+
+.. note::
+
+    This page references all Portal error codes.
+
+.. csv-table::
+   :header: "Error label", "Error number"
+   :delim: ;
+   :widths: auto
+
+
+EOF
+
+    for my $key (
+        sort { $portalConstants{$a} <=> $portalConstants{$b} }
+        keys %portalConstants
+      )
+    {
+
+        $content .= "    ``" . $key . "``;" . $portalConstants{$key} . "\n";
+    }
+
+    open( F, '>', $self->docConstantsFile ) or die($!);
+    print F $content;
+    close F;
+
+    print STDERR "done\n";
 }
 
 sub mydump {
@@ -705,9 +743,9 @@ sub scanTree {
                 push @cnodesKeys, $leaf;
             }
 
-    # issue 2439
-    # FIXME: in future versions, oidcOPMetaDataJSON and samlIDPMetaDataXML should
-    # behave the same
+   # issue 2439
+   # FIXME: in future versions, oidcOPMetaDataJSON and samlIDPMetaDataXML should
+   # behave the same
             if ( $leaf =~ /^oidcOPMetaData(?:JSON|JWKS)$/ ) {
                 push @simpleHashKeys, $leaf;
             }
